import { NoticeRep } from "@/api/home";
import { create } from "zustand";

interface State {
    sourceMap: Map<number, NoticeRep>;
}

interface Action {
    setSourceMap: (key: number, value: NoticeRep) => void;
    hasValue: (key: number) => boolean;
}

const initialState: State = {
    sourceMap: new Map(),
};

export const useGlobalNoticeStore = create<State & Action>()((set, get) => {
    return {
        ...initialState,
        setSourceMap: (key, value) =>
            set((state) => {
                const newMap = new Map(state.sourceMap);
                newMap.set(key, value);
                return { sourceMap: newMap };
            }),

        hasValue: (key) => get().sourceMap.has(key),
        reset: () => set(initialState),
    };
});
